summaryrefslogtreecommitdiff
path: root/src/keyboardconfig.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/keyboardconfig.h')
-rw-r--r--src/keyboardconfig.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/src/keyboardconfig.h b/src/keyboardconfig.h
index f6439795..716f9a17 100644
--- a/src/keyboardconfig.h
+++ b/src/keyboardconfig.h
@@ -103,9 +103,9 @@ class KeyboardConfig
int getKeyIndex(int keyValue) const;
/**
* Get the key function index for smiley by providing the offset value.
*/
- int getKeySmilieOffset(int keyValue) const;
+ int getKeyEmoteOffset(int keyValue) const;
/**
* Set the enable flag, which will stop the user from doing actions.
@@ -147,8 +147,6 @@ class KeyboardConfig
* KEY_TOTAL should always be last (used as a conditional in loops).
* The key assignment view gets arranged according to the order of
* these values.
- *
- * KEY_SMILEY_* must be also at the end (just before KEY_TOTAL)
*/
enum KeyAction {
KEY_NO_VALUE = -1,
@@ -157,7 +155,7 @@ class KeyboardConfig
KEY_MOVE_LEFT,
KEY_MOVE_RIGHT,
KEY_ATTACK,
- KEY_SMILIE,
+ KEY_EMOTE,
KEY_TALK,
KEY_TARGET,
KEY_TARGET_CLOSEST,
@@ -166,7 +164,6 @@ class KeyboardConfig
KEY_PICKUP,
KEY_HIDE_WINDOWS,
KEY_SIT,
- KEY_SHORTCUT_0,
KEY_SHORTCUT_1,
KEY_SHORTCUT_2,
KEY_SHORTCUT_3,
@@ -176,6 +173,9 @@ class KeyboardConfig
KEY_SHORTCUT_7,
KEY_SHORTCUT_8,
KEY_SHORTCUT_9,
+ KEY_SHORTCUT_10,
+ KEY_SHORTCUT_11,
+ KEY_SHORTCUT_12,
KEY_WINDOW_STATUS,
KEY_WINDOW_INVENTORY,
KEY_WINDOW_EQUIPMENT,
@@ -185,20 +185,20 @@ class KeyboardConfig
KEY_WINDOW_SHORTCUT,
KEY_WINDOW_SETUP,
KEY_WINDOW_DEBUG,
- KEY_WINDOW_ALLSMILEY,
- KEY_WINDOW_SMILEY_SHORTCUT,
- KEY_SMILEY_1,
- KEY_SMILEY_2,
- KEY_SMILEY_3,
- KEY_SMILEY_4,
- KEY_SMILEY_5,
- KEY_SMILEY_6,
- KEY_SMILEY_7,
- KEY_SMILEY_8,
- KEY_SMILEY_9,
- KEY_SMILEY_10,
- KEY_SMILEY_11,
- KEY_SMILEY_12,
+ KEY_WINDOW_EMOTE,
+ KEY_WINDOW_EMOTE_SHORTCUT,
+ KEY_EMOTE_1,
+ KEY_EMOTE_2,
+ KEY_EMOTE_3,
+ KEY_EMOTE_4,
+ KEY_EMOTE_5,
+ KEY_EMOTE_6,
+ KEY_EMOTE_7,
+ KEY_EMOTE_8,
+ KEY_EMOTE_9,
+ KEY_EMOTE_10,
+ KEY_EMOTE_11,
+ KEY_EMOTE_12,
KEY_TOTAL
};
@@ -103,9 +103,9 @@ class KeyboardConfig
int getKeyIndex(int keyValue) const;
/**
- * Get the key function index for smiley by providing the offset value.
+ * Get the key function index for an emote by providing the offset value.
*/